==> istio-model-v1alpha3-6.5.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterClusterMatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterClusterMatchFluentImpl<A extends EnvoyFilterClusterMatchFluent<A>> extends BaseFluent<A> implements EnvoyFilterClusterMatchFluent<A>{
  public EnvoyFilterClusterMatchFluentImpl() {
  }
  public EnvoyFilterClusterMatchFluentImpl(EnvoyFilterClusterMatch instance) {
    this.withName(instance.getName()); 
    this.withPortNumber(instance.getPortNumber()); 
    this.withService(instance.getService()); 
    this.withSubset(instance.getSubset()); 
  }
  private String name;
  private Integer portNumber;
  private String service;
  private String subset;
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public Integer getPortNumber() {
    return this.portNumber;
  }
  public A withPortNumber(Integer portNumber) {
    this.portNumber=portNumber; return (A) this;
  }
  public Boolean hasPortNumber() {
    return this.portNumber != null;
  }
  public String getService() {
    return this.service;
  }
  public A withService(String service) {
    this.service=service; return (A) this;
  }
  public Boolean hasService() {
    return this.service != null;
  }
  public String getSubset() {
    return this.subset;
  }
  public A withSubset(String subset) {
    this.subset=subset; return (A) this;
  }
  public Boolean hasSubset() {
    return this.subset != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EnvoyFilterClusterMatchFluentImpl that = (EnvoyFilterClusterMatchFluentImpl) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (portNumber != null ? !portNumber.equals(that.portNumber) :that.portNumber != null) return false;
    if (service != null ? !service.equals(that.service) :that.service != null) return false;
    if (subset != null ? !subset.equals(that.subset) :that.subset != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  portNumber,  service,  subset,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (portNumber != null) { sb.append("portNumber:"); sb.append(portNumber + ","); }
    if (service != null) { sb.append("service:"); sb.append(service + ","); }
    if (subset != null) { sb.append("subset:"); sb.append(subset); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterClusterMatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterClusterMatchFluentImpl<A extends EnvoyFilterClusterMatchFluent<A>> extends BaseFluent<A> implements EnvoyFilterClusterMatchFluent<A>{
  public EnvoyFilterClusterMatchFluentImpl() {
  }
  public EnvoyFilterClusterMatchFluentImpl(EnvoyFilterClusterMatch instance) {
    if (instance != null) {
      this.withName(instance.getName());
      this.withPortNumber(instance.getPortNumber());
      this.withService(instance.getService());
      this.withSubset(instance.getSubset());
    }
  }
  private String name;
  private Integer portNumber;
  private String service;
  private String subset;
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public Integer getPortNumber() {
    return this.portNumber;
  }
  public A withPortNumber(Integer portNumber) {
    this.portNumber=portNumber; return (A) this;
  }
  public Boolean hasPortNumber() {
    return this.portNumber != null;
  }
  public String getService() {
    return this.service;
  }
  public A withService(String service) {
    this.service=service; return (A) this;
  }
  public Boolean hasService() {
    return this.service != null;
  }
  public String getSubset() {
    return this.subset;
  }
  public A withSubset(String subset) {
    this.subset=subset; return (A) this;
  }
  public Boolean hasSubset() {
    return this.subset != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterClusterMatchFluentImpl that = (EnvoyFilterClusterMatchFluentImpl) o;
    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(portNumber, that.portNumber)) return false;

    if (!java.util.Objects.equals(service, that.service)) return false;

    if (!java.util.Objects.equals(subset, that.subset)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  portNumber,  service,  subset,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (portNumber != null) { sb.append("portNumber:"); sb.append(portNumber + ","); }
    if (service != null) { sb.append("service:"); sb.append(service + ","); }
    if (subset != null) { sb.append("subset:"); sb.append(subset); }
    sb.append("}");
    return sb.toString();
  }
  
}
